"""
Empirica Dashboard Components

Terminal-based monitoring for epistemic snapshots and system health.
"""

__all__ = ['SnapshotMonitor', 'launch_dashboard']

from .snapshot_monitor import SnapshotMonitor, launch_dashboard
